#! /usr/bin/env python
# -*- coding: utf-8 -*-

"""
Module that defines package version for tpDcc-libs-python
"""

from __future__ import print_function, division, absolute_import

__version__ = "0.0.3"
